@@ -14,6 +14,7 @@
 
 #include <config-X11.h>
 
+#include <QApplication>
 #include <QDir>
 #include <QIcon>
 #include <QMimeDatabase>
@@ -30,6 +31,8 @@
 #include <KActivities/ResourceInstance>
 #include <KFileItem>
 #include <KIO/ApplicationLauncherJob>
+#include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
 #include <KIO/OpenFileManagerWindowJob>
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
@@ -230,12 +233,16 @@ QVariant RecentUsageModel::appData(const QString &resource, int role) const
 
         const QVariantList &jumpList = Kicker::jumpListActions(service);
         if (!jumpList.isEmpty()) {
-            actionList << jumpList << Kicker::createSeparatorActionItem();
+            actionList << jumpList;
         }
 
         const QVariantList &recentDocuments = Kicker::recentDocumentActions(service);
         if (!recentDocuments.isEmpty()) {
-            actionList << recentDocuments << Kicker::createSeparatorActionItem();
+            actionList << recentDocuments;
+        }
+
+        if (!actionList.isEmpty()) {
+            actionList << Kicker::createSeparatorActionItem();
         }
 
         const QVariantMap &forgetAction = Kicker::createActionItem(i18n("Forget Application"), QStringLiteral("edit-clear-history"), QStringLiteral("forget"));
@@ -361,7 +368,8 @@ bool RecentUsageModel::trigger(int row, const QString &actionId, const QVariant
             const QUrl resourceUrl = docData(resource, Kicker::UrlRole, mimeType).toUrl();
 
             auto job = new KIO::OpenUrlJob(resourceUrl);
-            job->setRunExecutables(false);
+            job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, QApplication::activeWindow()));
+            job->setShowOpenOrExecuteDialog(true);
             job->start();
 
             return true;
